# Layers API Reference

## Attention

::: lmt.layers.attention.MultiHeadAttention

::: lmt.layers.attention.GroupedQueryAttention

::: lmt.layers.attention.SlidingWindowAttention

::: lmt.layers.attention.MultiHeadLatentAttention

## Feed-Forward Networks

::: lmt.layers.ffn.SwiGLU

::: lmt.layers.ffn.MoEFeedForward

## Normalization

::: lmt.layers.normalization.RMSNorm

## Attention Utilities

::: lmt.layers.attention.KVCache

## Positional Encoding

::: lmt.layers.positional.RoPE

::: lmt.layers.positional.ALiBi
